# Modern Pytest

[![uv](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/uv/main/assets/badge/v0.json)](https://github.com/astral-sh/uv)
[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff)
![GitHub License](https://img.shields.io/github/license/zen-xu/pytest-modern)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/pytest-modern)
![PyPI - Version](https://img.shields.io/pypi/v/pytest-modern)

This plugin incorporates ideas from the implementation of [pytest-rich](https://github.com/nicoddemus/pytest-rich) and takes inspiration from the output style of [nextest](https://nexte.st).

With the plugin currently outputs this:
![image](assets/screenshot.jpg)
